@@ -654,7 +654,7 @@ public class ColumnDataComboBoxModel
          */
         SyntheticColumnData( TopcatModel tcModel, String expr )
                 throws CompilationException {
-            super( new DefaultValueInfo( expr ), expr, null,
+            super( new ColumnInfo( expr ), expr, null,
                    tcModel.createJELRowReader() );
             tcModel_ = tcModel;
             expr_ = expr;
