@@ -127,13 +127,9 @@ import uk.ac.starlink.util.gui.DragListener;
 import uk.ac.starlink.util.gui.ErrorDialog;
 import uk.ac.starlink.util.gui.MemoryMonitor;
 import uk.ac.starlink.util.gui.StringPaster;
-import uk.ac.starlink.vo.ConeSearchDialog;
 import uk.ac.starlink.vo.DalLoader;
-import uk.ac.starlink.vo.SiapTableLoadDialog;
 import uk.ac.starlink.vo.SkyDalTableLoadDialog;
 import uk.ac.starlink.vo.SkyPositionEntry;
-import uk.ac.starlink.vo.SsapTableLoadDialog;
-import uk.ac.starlink.vo.TapTableLoadDialog;
 
 /**
  * Main window providing user control of the TOPCAT application.
@@ -918,10 +914,10 @@ public class ControlWindow extends AuxWindow
             }
             public void acceptRow( Object[] row ) {
                 StringBuffer sbuf = new StringBuffer();
-                sbuf.append( ++irow );
+                sbuf.append( TopcatUtils.formatLong( ++irow ) );
                 if ( nrow > 0 ) {
                     sbuf.append( '/' );
-                    sbuf.append( nrow );
+                    sbuf.append( TopcatUtils.formatLong( nrow ) );
                 }
                 token.setProgress( sbuf.toString() );
             }
@@ -1116,6 +1112,11 @@ public class ControlWindow extends AuxWindow
                             || ((SkyDalTableLoadDialog) tld)
                               .acceptSkyPosition( raDegrees, decDegrees );
                 }
+                else if ( tld instanceof TopcatTapTableLoadDialog ) {
+                    accepted = accepted
+                            || ((TopcatTapTableLoadDialog) tld)
+                              .acceptSkyPosition( raDegrees, decDegrees );
+                }
             }
         }
         return accepted;
