@@ -193,7 +193,6 @@ public class Driver {
      */
     private static void runMain( String[] args )
             throws SampException, IOException {
-        VOElementFactory.STRICT_DEFAULT = false;
         tabfact = TopcatPreparation.createFactory();
         String cmdname;
         try {
@@ -377,6 +376,12 @@ public class Driver {
         /* Install custom URL handlers. */
         URLUtils.installCustomHandlers();
 
+        /* Set up an authenticator for HTTP 401s.  If properties are
+         * supplied, use those, otherwise use one which will pop up a window. */
+        if ( ! PropertyAuthenticator.installInstance( false ) ) {
+            Authenticator.setDefault( new SwingHttpAuthenticator( null ) );
+        }
+
         /* Assemble pairs of (table name, handler name) to be loaded. */
         final List<DataSourceLoader> loaderList =
             new ArrayList<DataSourceLoader>();
@@ -442,12 +447,6 @@ public class Driver {
         /* Start up the GUI now. */
         final ControlWindow control = getControlWindow();
 
-        /* Set up an authenticator for HTTP 401s.  If properties are
-         * supplied, use those, otherwise use one which will pop up a window. */
-        if ( ! PropertyAuthenticator.installInstance( false ) ) {
-            Authenticator.setDefault( new SwingHttpAuthenticator( control ) );
-        }
-
         /* Start up with demo data if requested. */
         if ( demo ) {
             StarTable[] demoTables = getDemoTables();
