@@ -11,7 +11,6 @@ import javax.swing.table.TableColumn;
 import javax.swing.table.TableColumnModel;
 import uk.ac.starlink.table.ColumnData;
 import uk.ac.starlink.table.ColumnInfo;
-import uk.ac.starlink.table.DefaultValueInfo;
 import uk.ac.starlink.table.DescribedValue;
 import uk.ac.starlink.table.gui.LabelledComponentStack;
 import uk.ac.starlink.table.gui.StarTableColumn;
@@ -25,7 +24,6 @@ import uk.ac.starlink.util.gui.CustomComboBoxRenderer;
 public class SyntheticColumnQueryWindow extends QueryWindow {
 
     private final TopcatModel tcModel;
-    private final OptionsListModel subsets;
     private final TableColumnModel columnModel;
     private JTextField nameField;
     private JTextField unitField;
@@ -50,7 +48,6 @@ public class SyntheticColumnQueryWindow extends QueryWindow {
         super( "Define Synthetic Column", parent );
         this.tcModel = tcModel;
         this.columnModel = tcModel.getColumnModel();
-        this.subsets = tcModel.getSubsets();
         LabelledComponentStack stack = getStack();
 
         /* Name field. */
@@ -238,7 +235,7 @@ public class SyntheticColumnQueryWindow extends QueryWindow {
         String expr = getExpression();
         String ucd = getUCD();
         Class clazz = getExpressionType();
-        DefaultValueInfo info = new DefaultValueInfo( name );
+        ColumnInfo info = new ColumnInfo( name );
         if ( desc != null ) {
             info.setDescription( desc );
         }
