@@ -73,7 +73,7 @@ public class TopcatModel {
     private final ViewerTableModel viewModel_;
     private final TableColumnModel columnModel_;
     private final ColumnList columnList_;
-    private final OptionsListModel subsets_;
+    private final OptionsListModel<RowSubset> subsets_;
     private final Map subsetCounts_;
     private final ComboBoxModel sortSelectionModel_;
     private final ComboBoxModel subsetSelectionModel_;
@@ -182,7 +182,7 @@ public class TopcatModel {
         sortSenseModel_ = new SortSenseModel();
 
         /* Initialise subsets list. */
-        subsets_ = new OptionsListModel();
+        subsets_ = new OptionsListModel<RowSubset>();
         subsets_.add( RowSubset.ALL );
 
         /* Set up the current subset selector. */
@@ -340,7 +340,7 @@ public class TopcatModel {
      *
      * @return   the RowSubset list model
      */
-    public OptionsListModel getSubsets() {
+    public OptionsListModel<RowSubset> getSubsets() {
         return subsets_;
     }
 
@@ -669,18 +669,16 @@ public class TopcatModel {
         String baseExpr = baseInfo.getAuxDatum( TopcatUtils.COLID_INFO )
                                   .getValue().toString();
         ColumnInfo elInfo = new ColumnInfo( baseInfo );
-        RandomJELRowReader rowReader =
-            new TopcatJELRowReader( dataModel_,
-                                    new RowSubset[ 0 ], new int[ 0 ] );
+        RandomJELRowReader rowReader = createJELRowReader();
         elInfo.setShape( null );
         int ipos = 0;
-        for ( Iterator it = new ShapeIterator( baseInfo.getShape() );
+        for ( Iterator<int[]> it = new ShapeIterator( baseInfo.getShape() );
               it.hasNext(); ipos++ ) {
-            int[] pos = (int[]) it.next();
+            int[] pos = it.next();
             StringBuffer postxt = new StringBuffer();
-            for ( int i = 0; i < pos.length; i++ ) {
+            for ( int coord : pos ) {
                 postxt.append( '_' );
-                postxt.append( Integer.toString( pos[ i ] + 1 ) );
+                postxt.append( Integer.toString( coord + 1 ) );
             }
             ColumnInfo colInfo = new ColumnInfo( elInfo );
             colInfo.setName( baseName + postxt.toString() );
@@ -786,14 +784,7 @@ public class TopcatModel {
      * @return  row reader
      */
     public RandomJELRowReader createJELRowReader() {
-        int nset = subsets_.size();
-        RowSubset[] subsetArray = new RowSubset[ nset ];
-        int[] subsetIds = new int[ nset ];
-        for ( int isub = 0; isub < nset; isub++ ) {
-            subsetArray[ isub ] = (RowSubset) subsets_.get( isub );
-            subsetIds[ isub ] = subsets_.indexToId( isub );
-        }
-        return new TopcatJELRowReader( dataModel_, subsetArray, subsetIds );
+        return new TopcatJELRowReader( this );
     }
 
     /**
@@ -810,7 +801,7 @@ public class TopcatModel {
         boolean done = false;
         int nset = subsets_.size();
         for ( int is = 0; is < nset && ! done; is++ ) {
-            RowSubset rs = (RowSubset) subsets_.get( is );
+            RowSubset rs = subsets_.get( is );
             if ( rset != RowSubset.ALL &&
                  rset.getName().equals( rs.getName() ) ) {
                 subsets_.set( is, rset );
@@ -838,7 +829,7 @@ public class TopcatModel {
         RandomJELRowReader jeller = createJELRowReader();
         int nset = subsets_.size();
         for ( int is = 0; is < nset; is++ ) {
-            RowSubset rs = (RowSubset) subsets_.get( is );
+            RowSubset rs = subsets_.get( is );
             if ( rs instanceof SyntheticRowSubset ) {
                 SyntheticRowSubset ss = (SyntheticRowSubset) rs;
                 try {
