@@ -1,6 +1,10 @@
 package uk.ac.starlink.topcat;
 
+import java.awt.Desktop;
 import java.awt.Dimension;
+import java.awt.Toolkit;
+import java.awt.datatransfer.Clipboard;
+import java.awt.datatransfer.StringSelection;
 import java.io.IOException;
 import java.io.InputStream;
 import java.net.URL;
@@ -22,6 +26,7 @@ import javax.swing.JComponent;
 import javax.swing.JLabel;
 import javax.swing.JOptionPane;
 import javax.swing.SwingUtilities;
+import javax.swing.table.TableColumnModel;
 import uk.ac.starlink.table.ColumnInfo;
 import uk.ac.starlink.table.DefaultValueInfo;
 import uk.ac.starlink.table.DescribedValue;
@@ -50,6 +55,7 @@ public class TopcatUtils {
     private static String stilVersion_;
     private static DecimalFormat longFormat_;
     private static Map statusMap_;
+    private static Boolean canBrowse_;
     private static Logger logger_ = Logger.getLogger( "uk.ac.starlink.topcat" );
 
     static final TopcatCodec DFLT_SESSION_ENCODER;
@@ -89,14 +95,6 @@ public class TopcatUtils {
         new DefaultValueInfo( "Decoder", ValueConverter.class,
                               "Converts from string to numeric values" );
 
-    /**
-     * Parameter key for storing an activation action for a table.
-     */
-    public final static ValueInfo ACTIVATORS_INFO =
-        new DefaultValueInfo( "topcat-activation", String.class,
-                              "Action which can be performed " +
-                              "on row activation" );
-
     /**
      * Data identifier for epoch-type data.
      */
@@ -290,6 +288,62 @@ public class TopcatUtils {
         return about_;
     }
 
+    /**
+     * Returns the values from a row of a given table as a list of
+     * DescribedValues, suitable for use as parameters (per-value metadata)
+     * of a StarTable.
+     *
+     * @param  tcModel  table supplying values
+     * @param  lrow    row index
+     * @return   list of described values
+     */
+    public static List<DescribedValue> getRowAsParameters( TopcatModel tcModel,
+                                                           long lrow ) {
+        StarTable table = tcModel.getDataModel();
+        TableColumnModel tcm = tcModel.getColumnModel();
+        int ncol = tcm.getColumnCount();
+        List<DescribedValue> list = new ArrayList<DescribedValue>( ncol );
+        try {
+            Object[] row = table.getRow( lrow );
+            for ( int icol = 0; icol < ncol; icol++ ) {
+                int jcol = tcm.getColumn( icol ).getModelIndex();
+                ValueInfo info =
+                    new DefaultValueInfo( table.getColumnInfo( jcol ) );
+                list.add( new DescribedValue( info, row[ jcol ] ) );
+            }
+        }
+        catch ( IOException e ) {
+            logger_.log( Level.WARNING, "Trouble reading parameters: " + e, e );
+        }
+        return list;
+    }
+
+    /**
+     * Sets the text content of the system clipboard(s).
+     * This is somewhat OS-dependent.  X11 uses a PRIMARY selection
+     * (middle mouse button) alongside the CLIPBOARD selection
+     * (explicit cut'n'paste).  JTextComponents fill both, though
+     * not under exactly the same circumstances.  This method sets the
+     * text for both if both are available.
+     * This may not replicate exactly the behaviour expected by X clients,
+     * but I think it's what users would want to happen.  I may be wrong.
+     *
+     * @param  txt  text to set as clipboard contents
+     */
+    public static void setClipboardText( String txt ) {
+        StringSelection selection = new StringSelection( txt );
+        Toolkit toolkit = Toolkit.getDefaultToolkit();
+
+        /* Set the system clipboard to the given text. */
+        toolkit.getSystemClipboard().setContents( selection, null );
+
+        /* If there's a primary clipboard, set the text there too. */
+        Clipboard primary = toolkit.getSystemSelection();
+        if ( primary != null ) {
+            primary.setContents( selection, selection );
+        }
+    }
+
     /**
      * Alerts the user that the system has run out of memory, and provides
      * the option of some useful tips.
@@ -419,6 +473,26 @@ public class TopcatUtils {
         return canJel_.booleanValue();
     }
 
+    /**
+     * Returns a browse-capable desktop instance, or null if none is available.
+     *
+     * @return  desktop
+     */
+    public synchronized static Desktop getBrowserDesktop() {
+        if ( canBrowse_ == null ) {
+            boolean canBrowse =
+                   Desktop.isDesktopSupported()
+                && Desktop.getDesktop().isSupported( Desktop.Action.BROWSE );
+            if ( ! canBrowse ) {
+                logger_.warning( "Can't send URLs to browser"
+                               + " (no Desktop.Action.BROWSE" );
+            }
+            canBrowse_ = Boolean.valueOf( canBrowse );
+        }
+        return canBrowse_.booleanValue() ? Desktop.getDesktop()
+                                         : null;
+    }
+
     /**
      * Returns the version string for this copy of TOPCAT.
      *
