@@ -12,10 +12,13 @@ import javax.swing.Box;
 import javax.swing.ComboBoxModel;
 import javax.swing.JComboBox;
 import javax.swing.JComponent;
+import javax.swing.JLabel;
+import uk.ac.starlink.topcat.AlignedBox;
 import uk.ac.starlink.topcat.LineBox;
 import uk.ac.starlink.topcat.RowSubset;
 import uk.ac.starlink.topcat.TablesListComboBox;
 import uk.ac.starlink.topcat.TopcatModel;
+import uk.ac.starlink.topcat.TypedListModel;
 import uk.ac.starlink.ttools.plot2.DataGeom;
 import uk.ac.starlink.ttools.plot2.LegendEntry;
 import uk.ac.starlink.ttools.plot2.PlotLayer;
@@ -54,6 +57,7 @@ public class BasicCoordLayerControl extends ConfigControl
      * @param   zsel    zone id specifier, may be null for single-zone case
      * @param   coordPanel   panel which displays the plotter's coordinates,
      *                       and supplies a DataGeom
+     * @param   tablesModel  list of available tables
      * @param   baseConfigger   provides global configuration info
      * @param  autoPopulate  if true, when the table is changed an attempt
      *                       will be made to initialise the coordinate fields
@@ -61,6 +65,7 @@ public class BasicCoordLayerControl extends ConfigControl
      */
     public BasicCoordLayerControl( Plotter<?> plotter, Specifier<ZoneId> zsel,
                                    PositionCoordPanel coordPanel,
+                                   TypedListModel<TopcatModel> tablesModel,
                                    Configger baseConfigger,
                                    boolean autoPopulate ) {
         super( null, plotter.getPlotterIcon() );
@@ -72,7 +77,7 @@ public class BasicCoordLayerControl extends ConfigControl
         styler_ = new ConfigStyler( coordPanel_.getComponent() );
 
         /* Create data selection components. */
-        tableSelector_ = new TablesListComboBox();
+        tableSelector_ = new TablesListComboBox( tablesModel, 250 );
         subsetSelector_ = new JComboBox();
         dummyComboBoxModel_ = subsetSelector_.getModel();
 
@@ -90,10 +95,12 @@ public class BasicCoordLayerControl extends ConfigControl
         subsetSelector_.addActionListener( forwarder );
 
         /* Configure panel for specifying the data. */
-        JComponent dataPanel = Box.createVerticalBox();
-        dataPanel.add( new LineBox( "Table",
-                                    new ShrinkWrapper( tableSelector_ ),
-                                    true ) );
+        JComponent dataPanel = AlignedBox.createVerticalBox();
+        JComponent tline = Box.createHorizontalBox();
+        tline.add( new JLabel( "Table: " ) );
+        tline.add( tableSelector_ );
+        dataPanel.add( tline );
+        dataPanel.add( Box.createVerticalStrut( 5 ) );
         dataPanel.add( coordPanel_.getComponent() );
         dataPanel.add( Box.createVerticalStrut( 5 ) );
         dataPanel.add( new LineBox( "Row Subset",
@@ -160,6 +167,10 @@ public class BasicCoordLayerControl extends ConfigControl
         return zsel_;
     }
 
+    public TablesListComboBox getTableSelector() {
+        return tableSelector_;
+    }
+
     @Override
     public ConfigMap getConfig() {
         ConfigMap config = super.getConfig();
