@@ -18,6 +18,7 @@ import uk.ac.starlink.topcat.ResourceIcon;
 import uk.ac.starlink.topcat.RowSubset;
 import uk.ac.starlink.topcat.TopcatListener;
 import uk.ac.starlink.topcat.TopcatModel;
+import uk.ac.starlink.topcat.TypedListModel;
 import uk.ac.starlink.ttools.plot.Styles;
 import uk.ac.starlink.ttools.plot2.PlotType;
 import uk.ac.starlink.ttools.plot2.PlotUtil;
@@ -31,6 +32,7 @@ import uk.ac.starlink.ttools.plot2.data.Coord;
 import uk.ac.starlink.ttools.plot2.data.CoordGroup;
 import uk.ac.starlink.ttools.plot2.data.FloatingCoord;
 import uk.ac.starlink.ttools.plot2.data.Input;
+import uk.ac.starlink.util.Loader;
 
 /**
  * Control manager that uses FormLayerControls to provide
@@ -46,6 +48,7 @@ public class GroupControlManager implements ControlManager {
     private final ControlStack stack_;
     private final PlotType plotType_;
     private final PlotTypeGui plotTypeGui_;
+    private final TypedListModel<TopcatModel> tablesModel_;
     private final ZoneFactory zfact_;
     private final MultiConfigger baseConfigger_;
     private final TopcatListener tcListener_;
@@ -56,12 +59,22 @@ public class GroupControlManager implements ControlManager {
     private static final Logger logger_ =
         Logger.getLogger( "uk.ac.starlink.topcat.plot2" );
 
+    /**
+     * System property that may contain a colon-separated list of
+     * Plotter implementation class names (with no-arg constructors)
+     * to plug in at runtime.
+     * This is a bit scrappy - they will show up in all plot types,
+     * which probably is not appropriate.
+     */
+    public static final String PLOTTERS_PROP = "plot2.plotters";
+
     /**
      * Constructor.
      *
      * @param   stack  control stack which this object will manage
      * @param   plotType  defines basic plot characteristics
      * @param   plotTypeGui  defines GUI-specific plot characteristics
+     * @param   tablesModel   list of available tables
      * @param   zfact   zone id factory
      * @param   baseConfigger  configuration source for some global config
      *                        options
@@ -70,12 +83,14 @@ public class GroupControlManager implements ControlManager {
      *                     selected TopcatModel
      */
     public GroupControlManager( ControlStack stack, PlotType plotType,
-                                PlotTypeGui plotTypeGui, ZoneFactory zfact,
-                                MultiConfigger baseConfigger,
+                                PlotTypeGui plotTypeGui,
+                                TypedListModel<TopcatModel> tablesModel,
+                                ZoneFactory zfact, MultiConfigger baseConfigger,
                                 TopcatListener tcListener ) {
         stack_ = stack;
         plotType_ = plotType;
         plotTypeGui_ = plotTypeGui;
+        tablesModel_ = tablesModel;
         zfact_ = zfact;
         baseConfigger_ = baseConfigger;
         tcListener_ = tcListener;
@@ -90,9 +105,12 @@ public class GroupControlManager implements ControlManager {
         for ( CoordsType ctyp : CoordsType.values() ) {
             plotterMap_.put( ctyp, new ArrayList<Plotter>() );
         }
-        Plotter[] plotters = plotType_.getPlotters();
-        for ( int i = 0; i < plotters.length; i++ ) {
-            Plotter plotter = plotters[ i ];
+        for ( Plotter plotter : plotType_.getPlotters() ) {
+            CoordsType ctyp = CoordsType.getInstance( plotter );
+            plotterMap_.get( ctyp ).add( plotter );
+        }
+        for ( Plotter plotter :
+              Loader.getClassInstances( PLOTTERS_PROP, Plotter.class ) ) {
             CoordsType ctyp = CoordsType.getInstance( plotter );
             plotterMap_.get( ctyp ).add( plotter );
         }
@@ -121,8 +139,9 @@ public class GroupControlManager implements ControlManager {
         for ( Plotter plotter : plotterMap_.get( CoordsType.MISC ) ) {
             Action stackAct =
                 LayerControlAction
-               .createPlotterAction( plotter, stack, zfact_, nextSupplier_,
-                                     tcListener_, baseConfigger_ );
+               .createPlotterAction( plotter, stack, tablesModel_, zfact_,
+                                     nextSupplier_, tcListener_,
+                                     baseConfigger_ );
             if ( stackAct != null ) {
                 stackActList.add( stackAct );
             }
@@ -322,8 +341,8 @@ public class GroupControlManager implements ControlManager {
             Specifier<ZoneId> zsel = zfact_.isSingleZone() ? null : zs0;
             boolean autoPop = ctyp.isAutoPopulate();
             MultiFormLayerControl control = 
-                new MultiFormLayerControl( coordPanel, zsel, autoPop,
-                                           nextSupplier_, tcListener_,
+                new MultiFormLayerControl( coordPanel, tablesModel_, zsel,
+                                           autoPop, nextSupplier_, tcListener_,
                                            ctyp.getIcon(),
                                            plotterList
                                           .toArray( new Plotter[ 0 ] ),
