@@ -50,6 +50,9 @@ public class SpherePlotWindow
         public boolean hasPositions() {
             return true;
         }
+        public boolean isPlanar() {
+            return false;
+        }
         public GangerFactory getGangerFactory() {
             return SingleGanger.FACTORY;
         }
